#include "combat_ui.hpp"
#include "constants.hpp"
#include "color.hpp"

namespace gui {
  using namespace guecs;

  CombatUI::CombatUI(GameLevel level) :
      $level(level)
  {
    $gui.position(COMBAT_UI_X, COMBAT_UI_Y, COMBAT_UI_WIDTH, COMBAT_UI_HEIGHT);
    $gui.layout(
        "[*%(100,150)button_attack | *%(100,150)button_block | *%(100,150)button_evade | *%(100,150)button_heal]");
  }

  void CombatUI::make_button(std::string name, std::wstring label, Events::GUI event, int action) {
    auto button = $gui.entity(name);
    $gui.set<Sprite>(button, {"leather_pouch-128"});
    $gui.set<Rectangle>(button, {});
    $gui.set<Sound>(button, {"ui_click"});
    $gui.set<Label>(button, {label});
    $gui.set<Effect>(button, {.duration=0.1f});
    $gui.set<Clickable>(button,
        guecs::make_action(*$level.world, event, {action}));
  }

  void CombatUI::init() {
    $gui.world().set_the<Background>({$gui.$parser, ColorValue::DARK_MID});
    make_button("button_attack", L"Attack", Events::GUI::ATTACK, 1);
    make_button("button_block", L"Block", Events::GUI::ATTACK, 2);
    make_button("button_evade", L"Evade", Events::GUI::EVADE, 0);
    make_button("button_heal", L"Heal", Events::GUI::HEAL, 0);
    $gui.init();
  }

  void CombatUI::render(sf::RenderWindow& window) {
    $gui.render(window);
  }

  void CombatUI::update_level(GameLevel &level) {
    $level = level;
    init();
  }

  bool CombatUI::mouse(float x, float y, bool hover) {
    return $gui.mouse(x, y, hover);
  }
}
